#! /usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * CLI
 * =====================
 * Command Line Interface
 *
 * @contributors: Eddie Cooro [@Eddie-Cooro]
 *
 * @license: MIT License
 *
 */
const fs_1 = __importDefault(require("fs"));
const posix_1 = __importDefault(require("path/posix"));
const yargs_1 = __importDefault(require("yargs"));
const helpers_1 = require("yargs/helpers");
const argv = (0, yargs_1.default)((0, helpers_1.hideBin)(process.argv))
    .usage(`Usage: $0 --dir ./libs/tools`)
    .option("dir", {
    type: "string",
    describe: "Directory in which the package and package-lock.json will be found",
})
    .example("$0 ./package.json ./package-lock.json", "Locks the package.json file based on versions declared inside of the package-lock.json")
    .example("$0 --dir ./libs/tools", "Locks the package.json file inside of the tools directory using the package-lock.json file in the same place")
    .example("$0", "Locks the package.json file inside of the current directory directory using the package-lock.json file in the same place")
    .help("help")
    .alias("help", "h").argv;
const dir = argv.dir || "./";
const [packagejsonPath = posix_1.default.join(dir, "package.json"), packageLockPath = posix_1.default.join(dir, "package-lock.json")] = argv._;
const packagejsonstr = fs_1.default.readFileSync(packagejsonPath, "utf8");
const packagelockstr = fs_1.default.readFileSync(packageLockPath, "utf8");
const packagejson = JSON.parse(packagejsonstr);
const packagelock = JSON.parse(packagelockstr);
const lockDependencies = packagelock.dependencies;
const getLockedDependenciesFor = (dependencies) => {
    return Object.fromEntries(Object.keys(dependencies).map((d) => {
        if (lockDependencies[d]) {
            return [d, `${lockDependencies[d].version}`];
        }
        else {
            throw new Error(`No lock dependency found for ${d}`);
        }
    }));
};
const lockedPackage = Object.assign(Object.assign(Object.assign(Object.assign({}, packagejson), (packagejson.dependencies ? { dependencies: getLockedDependenciesFor(packagejson.dependencies) } : {})), (packagejson.devDependencies ? { devDependencies: getLockedDependenciesFor(packagejson.devDependencies) } : {})), (packagejson.peerDependencies
    ? { peerDependencies: getLockedDependenciesFor(packagejson.peerDependencies) }
    : {}));
fs_1.default.writeFileSync(packagejsonPath, JSON.stringify(lockedPackage, null, 2), "utf8");
//# sourceMappingURL=cli.js.map